# DataJoint Element - Miniscope Calcium Imaging

DataJoint Element for functional calcium imaging data acquired with the [UCLA Miniscope](https://github.com/Aharoni-Lab/Miniscope-v4) and [Miniscope DAQ](https://github.com/Aharoni-Lab/Miniscope-DAQ-QT-Software) acquisition system, and analyzed with `CaImAn`. 
DataJoint Elements collectively standardize and automate data collection and analysis for neuroscience experiments.  Each Element is a modular pipeline for data storage and processing with corresponding database tables that can be combined with other Elements to assemble a fully functional pipeline.

Installation and usage instructions can be found at the 
[Element documentation](datajoint.com/docs/elements/element-miniscope).

![element-miniscope diagram](https://raw.githubusercontent.com/datajoint/element-miniscope/main/images/attached_miniscope_element.svg)